import { Account } from "../types/account";
import { BaseListParams, Include, Meta, Sort, Tags, UnitConfig, UnitResponse } from "../types/common";
import { Customer } from "../types/customer";
import { BulkPayments, CreatePaymentRequest, PatchPaymentRequest, Payment, PaymentStatus } from "../types/payments";
import { Transaction } from "../types/transactions";
import { BaseResource } from "./baseResource";
export declare class Payments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreatePaymentRequest): Promise<UnitResponse<Payment>>;
    createBulk(request: CreatePaymentRequest[]): Promise<UnitResponse<BulkPayments>>;
    update(id: string, request: PatchPaymentRequest): Promise<UnitResponse<Payment>>;
    cancel(id: string): Promise<UnitResponse<Payment>>;
    /**
     * Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account, transaction. See Getting Related Resources
     */
    get(id: string, include?: string): Promise<UnitResponse<Payment> & Include<Account[] | Customer[] | Transaction[]>>;
    list(params?: PaymentListParams): Promise<UnitResponse<Payment[]> & Include<Account[] | Customer[] | Transaction[]> & Meta>;
}
export interface PaymentListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter Applications by Tags.
     * default: empty
     */
    tags?: Tags;
    /**
     * Optional. Filter Payments by [ACH Status](https://developers.unit.co/payments/#ach-status).
     */
    status?: PaymentStatus[];
    /**
     * Optional. Filter Payments by Payment type. such as (ACHPayment, BookPayment, WirePayment).
     */
    type?: string[];
    /**
     * 	Optional. Filter Payments by direction. such as (Debit, Credit).
     */
    direction?: string[];
    /**
     * Optional. Filters the Payments that occurred after the specified date. e.g. 2020-01-13T16:01:19.346Z
     */
    since?: string;
    /**
     * Optional. Filters the Payments that occurred before the specified date. e.g. 2020-01-02T20:06:23.486Z
     */
    until?: string;
    /**
     * Optional. Filters the Payments by the account id of the specified counterparty.
     */
    counterpartyAccountId?: string;
    /**
     * Optional. Filters the Payments that have an amount that is higher or equal to the specified amount (in cents). e.g. 5000
     */
    fromAmount?: number;
    /**
     * Optional. Filters the Payments that have an amount that is lower or equal to the specified amount (in cents). e.g. 7000
     */
    toAmount?: number;
    /**
     * Optional. Leave empty or provide sort = createdAt for ascending order.Provide sort = -createdAt(leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: Sort;
    /**
    * Optional. A comma-separated list of related resources to include in the response.
    * Related resources include: customer, account. [See Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources)
    */
    include?: string;
    /**
     * Optional. Filters the results by the specified recurring payment id.
     */
    recurringPaymentId?: string;
    /**
     * Optional. Filter Payments by Payment feature (SameDay, RecurringPayment). Usage example: filter[feature][0]=SameDay
     */
    feature?: string[];
}
