"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Simulations = void 0;
const _1 = require(".");
class Simulations extends _1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/sandbox", config);
    }
    async approveApplication(applicationId, request) {
        return this.httpPost(`/applications/${applicationId}/approve`, {
            data: request,
        });
    }
    async denyApplication(applicationId, request) {
        return this.httpPost(`/applications/${applicationId}/deny`, {
            data: request,
        });
    }
    async approveDocument(applicationId, documentId) {
        return this.httpPost(`/applications/${applicationId}/documents/${documentId}/approve`, undefined);
    }
    async rejectDocument(applicationId, documentId, request) {
        return this.httpPost(`/applications/${applicationId}/documents/${documentId}/reject`, {
            data: request,
        });
    }
    async receiveAchPayment(request) {
        return this.httpPost("/payments", {
            data: request,
        });
    }
    async createAchReceivedPayment(request) {
        return this.httpPost("/received-payments", {
            data: request,
        });
    }
    async completeAchReceivedPayment(id) {
        return this.httpPost(`/received-payments/${id}/complete`);
    }
    async transmitAchPayment(request) {
        return this.httpPost("/ach/transmit", {
            data: request,
        });
    }
    async clearAchPayment(request) {
        return this.httpPost("/ach/clear", {
            data: request,
        });
    }
    async createCheckPayment(request) {
        return this.httpPost("/check-payments", { data: request });
    }
    async createCardPurchase(request) {
        return this.httpPost("/purchases", {
            data: request,
        });
    }
    async createCardAuthorization(request) {
        return this.httpPost("/authorizations", {
            data: request,
        });
    }
    async increaseCardAuthorization(request, authorizationId) {
        return this.httpPost(`/authorizations/${authorizationId}/increase`, {
            data: request,
        });
    }
    async cancelCardAuthorization(request, authorizationId) {
        return this.httpPost(`/authorizations/${authorizationId}/cancel`, {
            data: request,
        });
    }
    async createCardTransactionAuthorizationRequest(request) {
        return this.httpPost("authorization-requests/card-transaction", {
            data: request
        });
    }
    async createCardPurchaseAuthorizationRequest(request) {
        return this.httpPost("authorization-requests/purchase", {
            data: request
        });
    }
    async createAtmAuthorizationRequest(request) {
        return this.httpPost("authorization-requests/atm", {
            data: request
        });
    }
    async activateCard(id) {
        return this.httpPost(`/cards/${id}/activate`);
    }
    async atmWithdrawal(amount, account) {
        const req = {
            "type": "atmTransaction",
            "attributes": {
                "amount": amount,
                "atmName": "HOME FED SAV BK",
                "atmLocation": "Cupertino, CA, US",
                "last4Digits": "0019"
            },
            "relationships": {
                account
            }
        };
        return this.httpPost("/atm-withdrawals", req);
    }
}
exports.Simulations = Simulations;
