"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Statments = void 0;
const baseResource_1 = require("./baseResource");
class Statments extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/statements", config);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.period) && { "filter[period]": params.period }),
            ...((params === null || params === void 0 ? void 0 : params.sort) && { "sort": params.sort })
        };
        if (params === null || params === void 0 ? void 0 : params.accountIds)
            params.accountIds.forEach((id, idx) => {
                parameters[`filter[accountIds][${idx}]`] = id;
            });
        return this.httpGet("", { params: parameters });
    }
    get(statementId, customerId, isPDF = false, responseEncoding = "binary", language = "en") {
        const parameters = {
            ...(customerId && { "filter[customerId]": customerId }),
            language: language
        };
        const url = isPDF ? `/${statementId}/pdf` : `/${statementId}/html`;
        return this.httpGet(url, { params: parameters, responseEncoding });
    }
    getBinary(statementId, customerId, isPDF = false, language = "en") {
        return this.get(statementId, customerId, isPDF, "binary", language);
    }
    getBankVerification(accountId, includeProofOfFunds = false, responseEncoding = "binary", responseType = "blob") {
        return this.httpGet(`/${accountId}/bank/pdf`, { params: { includeProofOfFunds }, responseEncoding, responseType });
    }
}
exports.Statments = Statments;
